@@ -16,7 +16,6 @@ from morph_tool.converter import convert
 from morph_tool.exceptions import MorphToolException
 from morph_tool.morphdb import MorphDB
 from morph_tool.morphdb import MorphInfo
-from morph_tool.spatial import point_to_section_segment
 from morphio.mut import Morphology
 from neurom import load_morphology
 from neurom import view
@@ -24,10 +23,11 @@ from neuror.main import RepairType
 from neuror.main import repair as _repair
 from neuror.unravel import unravel as _unravel
 from neuror.zero_diameter_fixer import fix_zero_diameters as _fix_zero_diameters
-from scipy.spatial.ckdtree import cKDTree
+from scipy.spatial import KDTree
 from tqdm import tqdm
 
 from morphology_workflows.marker_helper import MarkerSet
+from morphology_workflows.utils import disable_loggers
 
 L = logging.getLogger(__name__)
 matplotlib.use("Agg")
@@ -44,14 +44,14 @@ def fix_zero_diameters(row, data_dir):
 
 def _map_apical(apical_point, mapping):
     """Map apical points as cut-leaves."""
-    t = cKDTree(mapping[["x0", "y0", "z0"]])
+    t = KDTree(mapping[["x0", "y0", "z0"]])
     _, indices = t.query(apical_point)
     return mapping.iloc[indices][["x1", "y1", "z1"]].values
 
 
 def _unravel_leaves(leaves, mapping):
     """Adapted from neuror.unraavel.unravel_plane."""
-    t = cKDTree(mapping[["x0", "y0", "z0"]])
+    t = KDTree(mapping[["x0", "y0", "z0"]])
     distances, indices = t.query(leaves)
     not_matching_leaves = np.where(distances > 1e-3)[0]
     if not_matching_leaves.size:
@@ -153,7 +153,9 @@ def plot_repair(row, data_dir, with_plotly=True):
         if markers is not None:
             points = markers.markers[0].data.T[[0, 2]]
 
-        with PdfPages(plot_path) as pdf:
+        with disable_loggers(
+            "matplotlib.font_manager", "matplotlib.backends.backend_pdf"
+        ), PdfPages(plot_path) as pdf:
             for plane in ["xy", "xz", "yz"]:
                 plt.figure()
                 ax = plt.gca()
@@ -177,30 +179,9 @@ def plot_repair(row, data_dir, with_plotly=True):
 
 
 def smooth_diameters(row, data_dir):
-    """Smooth diameters using diameter-synthesis."""
+    """Smooth diameters using diameter-synthesis simpler algorithm."""
     morph = Morphology(row.morph_path)
-
-    config = {
-        "model": {
-            "taper": {"max": 1e-06, "min": -0.5},
-            "terminal_threshold": 2.0,
-            "models": ["generic"],
-            "neurite_types": ["basal", "apical"],
-        },
-        "diameters": {
-            "models": ["neurite_based"],
-            "n_samples": 5,
-            "neurite_types": ["basal", "apical"],
-            "seed": 0,
-            "trunk_max_tries": 200,
-        },
-    }
-    if isinstance(row.apical_point_path, str):
-        apical_point = MarkerSet.from_file(row.apical_point_path).markers[0].data
-        apical_sec = [point_to_section_segment(morph, apical_point)[0]]
-    else:
-        apical_sec = None
-    diametrize_single_neuron(morph, config, apical_sec)
+    diametrize_single_neuron(morph)
     morph_path = data_dir / Path(row.morph_path).name
     morph.write(morph_path)
     return ValidationResult(is_valid=True, morph_path=morph_path)
@@ -226,7 +207,7 @@ def plot_smooth_diameters(row, data_dir, shift=200):
         soma_outline=False,
         realistic_diameters=False,
     )
-    plot_path = (data_dir / row.name).with_suffix(".png")
+    plot_path = (data_dir / row.name).with_suffix(".pdf")
     plt.autoscale()
     plt.axis("equal")
     plt.savefig(plot_path, bbox_inches="tight")
@@ -260,7 +241,9 @@ def make_collage(
     top_panel_shift += layer_boundaries[-1]
 
     mtypes = sorted(df.mtype.unique())
-    with PdfPages(data_dir.parent.parent / collage_path) as pdf:
+    with disable_loggers("matplotlib.font_manager", "matplotlib.backends.backend_pdf"), PdfPages(
+        data_dir.parent.parent / collage_path
+    ) as pdf:
         for mtype in tqdm(mtypes):
             _df = df[df.mtype == mtype]
             name_batches = np.array_split(_df.index, max(1, len(_df.index) / n_morph_per_page))
@@ -325,33 +308,23 @@ def make_collage(
 
 
 def _convert(input_file, output_file):
-    """Handles crashes in convertion of writing of morphologies."""
+    """Handles crashes in conversion of writing of morphologies."""
     try:
         convert(input_file, output_file)
         return output_file
     except MorphToolException:
         return "cannot save"
-
-
-def _get_layer_mtype(mtype_input):
-    """Helper to get layer from mtype, if mtype exists as a str."""
-    layer = "no_layer"
-    mtype = "no_mtype"
-    if isinstance(mtype_input, str):
-        mtype = mtype_input
-        if len(mtype_input) > 1:
-            layer = mtype_input[1]
-    return mtype, layer
+    except RuntimeError:  # this can happen if duplicates are being written as the same time
+        return output_file
 
 
 def _create_db_row(_data, zero_diameter_path, unravel_path, repair_path, extension):
     """Create a db row and convert morphology."""
-    name, data = _data
-    mtype, layer = _get_layer_mtype(data["mtype"])
+    index, data = _data
     m = MorphInfo(
-        name=name,
-        mtype=mtype,
-        layer=layer,
+        name=data["morph_name"],
+        mtype=data["mtype"],
+        layer=int(data["layer"]),
         use_dendrite=data["has_basal"],
         use_axon=data["has_axon"],
     )
@@ -376,11 +349,47 @@ def _create_db_row(_data, zero_diameter_path, unravel_path, repair_path, extensi
         data[f"repair_release_morph_path_{extension[1:]}"] = _convert(
             data["repair_morph_path"], repair_release_path
         )
-    return name, data, m
+    return index, data, m
 
 
-def make_release(df, _, zero_diameter_path, unravel_path, repair_path, extensions):
+def set_layer_column(df):
+    """Set layer values from mtype name if no layer column is present."""
+    for gid in df.index:
+        if df.loc[gid, "layer"] is None:
+            mtype = df.loc[gid, "mtype"]
+            if isinstance(mtype, str):
+                if len(mtype) > 1:
+                    try:
+                        layer = int(mtype[1])
+                    except ValueError:
+                        layer = 0
+            else:
+                layer = 0
+            df.loc[gid, "layer"] = layer
+            df.loc[gid, "mtype"] = mtype
+
+
+def add_duplicated_layers(df):
+    """Duplicate entries if layer name has mixed layers, i.e. L23_PC."""
+    for mtype in df.mtype.unique():
+        layer = mtype.split("_")[0][1:]
+        if len(layer) > 1:
+            _df = df[df.mtype == mtype]
+            _df.layer = int(layer[1])
+            df = pd.concat([df, _df]).reset_index(drop=True)
+    return df
+
+
+def make_release(
+    df, _, zero_diameter_path, unravel_path, repair_path, extensions, duplicate_layers=True
+):
     """Make morphology release."""
+    set_layer_column(df)
+
+    df_tmp = df.reset_index()
+    if duplicate_layers:
+        df_tmp = add_duplicated_layers(df_tmp)
+
     for extension in extensions:
         _zero_diameter_path = None
         if zero_diameter_path is not None:
@@ -406,26 +415,36 @@ def make_release(df, _, zero_diameter_path, unravel_path, repair_path, extension
         )
 
         _m = []
+        written = set()
         with Pool() as pool:
-            for name, row, m in pool.imap(__create_db_row, df.loc[df["is_valid"]].iterrows()):
-                df.loc[name] = pd.Series(row)
+            for index, row, m in tqdm(
+                pool.imap(__create_db_row, df_tmp.loc[df_tmp["is_valid"]].iterrows()),
+                total=len(df_tmp),
+            ):
+                if row["morph_name"] in df.index and row["morph_name"] not in written:
+                    df.loc[row["morph_name"]] = pd.Series(row)
+                    written.add(row["morph_name"])
+                df_tmp.loc[index] = pd.Series(row)
                 _m.append(m)
 
         db = MorphDB(_m)
         if _zero_diameter_path is not None:
             db.write(_zero_diameter_path / "neurondb.xml")
-            df.loc[df["is_valid"], f"zero_diameter_morph_db_path_{extension[:1]}"] = (
-                _zero_diameter_path / "neurondb.xml"
-            )
+            col_name = f"zero_diameter_morph_db_path_{extension[:1]}"
+            db_path = _zero_diameter_path / "neurondb.xml"
+            df.loc[df["is_valid"], col_name] = db_path
+            df_tmp.loc[df_tmp["is_valid"], col_name] = db_path
 
         if _unravel_path is not None:
             db.write(_unravel_path / "neurondb.xml")
-            df.loc[df["is_valid"], f"unravel_morph_db_path_{extension[1:]}"] = (
-                _unravel_path / "neurondb.xml"
-            )
+            col_name = f"unravel_morph_db_path_{extension[1:]}"
+            db_path = _unravel_path / "neurondb.xml"
+            df.loc[df["is_valid"], col_name] = db_path
+            df_tmp.loc[df_tmp["is_valid"], col_name] = db_path
 
         if _repair_path is not None:
             db.write(_repair_path / "neurondb.xml")
-            df.loc[df["is_valid"], f"repair_morph_db_path_{extension[1:]}"] = (
-                _repair_path / "neurondb.xml"
-            )
+            col_name = f"repair_morph_db_path_{extension[1:]}"
+            db_path = _repair_path / "neurondb.xml"
+            df.loc[df["is_valid"], col_name] = db_path
+            df_tmp.loc[df_tmp["is_valid"], col_name] = db_path
